@@ -10,20 +10,22 @@ class Worker(object):
     def run(self, cls, *args, **kargs):
         ins = cls(*args, **kargs)
         while 1:
-            print "wait", time.clock()
+            print 0, time.clock()
             task =  self.tq.GET_TASK()
-            print "wait 1", time.clock()
+            print 1, time.clock()
             key, method, args = task
             func = getattr(ins, method, None)
             if func:
                 # try:
+                print 2, time.clock()
                 result = func(*args)
+                print 3, time.clock()
                 # except Exception, e:
                 #   result = str(e)
             else:
                 result = "No Such Method!"
             self.tq.PUT_RESULT(key, result)
-            print "send", time.clock()
+            print 4, time.clock()
 
 
 class Runtime(object):
